ytree\.arbor\.frontends\.consistent\_trees\.arbor\.ConsistentTreesArbor
=======================================================================

.. currentmodule:: ytree.arbor.frontends.consistent_trees.arbor

.. autoclass:: ConsistentTreesArbor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ConsistentTreesArbor.__init__
      ~ConsistentTreesArbor.add_alias_field
      ~ConsistentTreesArbor.add_analysis_field
      ~ConsistentTreesArbor.add_derived_field
      ~ConsistentTreesArbor.is_grown
      ~ConsistentTreesArbor.is_setup
      ~ConsistentTreesArbor.save_arbor
      ~ConsistentTreesArbor.select_halos
      ~ConsistentTreesArbor.set_selector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ConsistentTreesArbor.arr
      ~ConsistentTreesArbor.box_size
      ~ConsistentTreesArbor.field_info
      ~ConsistentTreesArbor.hubble_constant
      ~ConsistentTreesArbor.quan
      ~ConsistentTreesArbor.size
      ~ConsistentTreesArbor.trees
      ~ConsistentTreesArbor.unit_registry
   
   